@@ -12,4 +12,9 @@ has allow_plugin => 1;
 has msg_time     => sub {time};
 has [qw(msg_id sender_id receiver_id sender receiver content raw_content cb)];
 
+sub text {
+    my $self = shift;
+    return $self->content if ref $self->raw_content ne "ARRAY";
+    return join "",map{$_->{content}} grep {$_->{type} eq "txt"} @{$self->{raw_content}};
+}
 1;
